redelay.core

Core API for creating and managing first class state objects.

Core API for creating and managing first class state objects.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries